# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/product/product.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.account import account_pb2 as services_dot_account_dot_account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eservices/product/product.proto\x12\x0esocial.product\x1a\x1cservices/common/common.proto\x1a\x1eservices/account/account.proto\"U\n\x12GetCategoryRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x33\n\x07options\x18\x02 \x01(\x0b\x32\".social.product.GetCategoryOptions\"_\n\x1bProductPublishStatusRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x0epublish_status\x18\x02 \x01(\x0b\x32\x1c.social.common.PublishStatus\"^\n\x1aReviewPublishStatusRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x0epublish_status\x18\x02 \x01(\x0b\x32\x1c.social.common.PublishStatus\"`\n\x11GetReviewsRequest\x12,\n\x06status\x18\x01 \x01(\x0b\x32\x1c.social.common.PublishStatus\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\"u\n\x12GetCategoryOptions\x12\r\n\x05props\x18\x01 \x01(\x08\x12\x0f\n\x07parents\x18\x02 \x01(\x08\x12\x10\n\x08\x63hildren\x18\x03 \x01(\x08\x12\x15\n\rprop_for_sort\x18\x04 \x01(\x08\x12\x16\n\x0eprop_for_price\x18\x05 \x01(\x08\"U\n\x1eGetAllCategoriesWithSubRequest\x12\x33\n\x07options\x18\x01 \x01(\x0b\x32\".social.product.GetCategoryOptions\"`\n\x17GetAllCategoriesRequest\x12\x10\n\x08position\x18\x01 \x01(\x05\x12\x33\n\x07options\x18\x02 \x01(\x0b\x32\".social.product.GetCategoryOptions\"x\n\x13\x46indCategoryRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x33\n\x07options\x18\x04 \x01(\x0b\x32\".social.product.GetCategoryOptions\"G\n\nGetProduct\x12(\n\x07product\x18\x01 \x01(\x0b\x32\x17.social.product.Product\x12\x0f\n\x07\x61s_post\x18\x02 \x01(\x08\"B\n\rGetAllRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\"`\n\x05Style\x12\x11\n\tfont_name\x18\x01 \x01(\t\x12\x13\n\x0b\x66ont_weight\x18\x02 \x01(\t\x12\x11\n\tfont_size\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\t\x12\r\n\x05\x63olor\x18\x05 \x01(\t\"c\n\rPropertyValue\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0e\n\x06weight\x18\x03 \x01(\x05\x12$\n\x05style\x18\x04 \x01(\x0b\x32\x15.social.product.Style\"\xb3\x01\n\x08Property\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12-\n\x06values\x18\x04 \x03(\x0b\x32\x1d.social.product.PropertyValue\x12\x11\n\tsmall_adj\x18\x05 \x01(\t\x12\x0f\n\x07\x62ig_adj\x18\x06 \x01(\t\x12$\n\x05style\x18\x07 \x01(\x0b\x32\x15.social.product.Style\"7\n\x0cPropertyList\x12\'\n\x05items\x18\x01 \x03(\x0b\x32\x18.social.product.Property\"\xcb\x03\n\x0fProductCategory\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04slug\x18\x04 \x01(\t\x12\x30\n\x07parents\x18\n \x03(\x0b\x32\x1f.social.product.ProductCategory\x12\x31\n\x08\x63hildren\x18\x05 \x03(\x0b\x32\x1f.social.product.ProductCategory\x12\'\n\x05props\x18\x06 \x03(\x0b\x32\x18.social.product.Property\x12/\n\rprop_for_sort\x18\x07 \x03(\x0b\x32\x18.social.product.Property\x12\x30\n\x0eprop_for_price\x18\x0c \x03(\x0b\x32\x18.social.product.Property\x12-\n\x04subs\x18\x0b \x03(\x0b\x32\x1f.social.product.SubCategoryItem\x12\x0e\n\x06weight\x18\x08 \x01(\x05\x12$\n\x05style\x18\t \x01(\x0b\x32\x15.social.product.Style\x12\x10\n\x08position\x18\r \x01(\x05\x12\x12\n\ncommission\x18\x0e \x01(\x02\"E\n\x13ProductCategoryList\x12.\n\x05items\x18\x01 \x03(\x0b\x32\x1f.social.product.ProductCategory\"M\n\x14ProductPropertyValue\x12&\n\x04prop\x18\x01 \x01(\x0b\x32\x18.social.product.Property\x12\r\n\x05value\x18\x02 \x01(\t\"L\n\x0bProductStat\x12\x12\n\nlike_count\x18\x01 \x01(\x03\x12\x12\n\nview_count\x18\x02 \x01(\x03\x12\x15\n\rcomment_count\x18\x03 \x01(\x03\"k\n\x07Pricing\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x02\x12*\n\x08\x63urrency\x18\x02 \x01(\x0e\x32\x18.social.product.Currency\x12\x10\n\x08\x64iscount\x18\x03 \x01(\x02\x12\x12\n\ncommission\x18\x04 \x01(\x02\"\x85\x01\n\x0cProductPrice\x12\'\n\x05props\x18\x02 \x03(\x0b\x32\x18.social.product.Property\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12&\n\x05price\x18\x04 \x01(\x0b\x32\x17.social.product.Pricing\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x05 \x01(\x08J\x04\x08\x01\x10\x02\"\xd8\x04\n\x07Product\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04slug\x18\x04 \x01(\t\x12\x0c\n\x04\x63ode\x18\x14 \x01(\t\x12\'\n\x05props\x18\x05 \x03(\x0b\x32\x18.social.product.Property\x12\x0f\n\x07\x63\x61t_ids\x18\x06 \x03(\t\x12-\n\x04\x63\x61ts\x18\x12 \x03(\x0b\x32\x1f.social.product.ProductCategory\x12&\n\x05owner\x18\x07 \x01(\x0b\x32\x17.social.account.Account\x12\x1b\n\x13is_comment_disabled\x18\x08 \x01(\x08\x12\x18\n\x10is_stat_disabled\x18\t \x01(\x08\x12(\n\nmedia_list\x18\n \x03(\x0b\x32\x14.social.common.Media\x12)\n\x04stat\x18\x0b \x01(\x0b\x32\x1b.social.product.ProductStat\x12\x10\n\x08hashtags\x18\x0c \x03(\t\x12\x13\n\x0b\x61rchived_at\x18\r \x01(\x03\x12\x12\n\ndeleted_at\x18\x0e \x01(\x03\x12$\n\x05style\x18\x0f \x01(\x0b\x32\x15.social.product.Style\x12\x10\n\x08is_liked\x18\x10 \x01(\x08\x12+\n\x05price\x18\x11 \x03(\x0b\x32\x1c.social.product.ProductPrice\x12\x34\n\x0epublish_status\x18\x13 \x01(\x0b\x32\x1c.social.common.PublishStatus\x12\x0e\n\x06rating\x18\x15 \x01(\x02\"5\n\x0bProductList\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.social.product.Product\"3\n\x0fPropertyForFind\x12\x0f\n\x07prop_id\x18\x01 \x01(\t\x12\x0f\n\x07reverse\x18\x02 \x01(\x08\"_\n\x08\x46indSort\x12$\n\x04sort\x18\x01 \x01(\x0e\x32\x16.social.product.SortBy\x12-\n\x04prop\x18\x02 \x01(\x0b\x32\x1f.social.product.PropertyForFind\"\x97\x01\n\x12\x46indProductRequest\x12(\n\x07product\x18\x01 \x01(\x0b\x32\x17.social.product.Product\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12&\n\x04sort\x18\x04 \x01(\x0b\x32\x18.social.product.FindSort\x12\x10\n\x08position\x18\x05 \x01(\x05\">\n\x0cRootCategory\x12.\n\x05items\x18\x01 \x03(\x0b\x32\x1f.social.product.ProductCategory\"^\n\x19SubCategoryContentRequest\x12\x31\n\x08\x63\x61tegory\x18\x01 \x01(\x0b\x32\x1f.social.product.ProductCategory\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\"\x8b\x01\n\x0fSubCategoryItem\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x31\n\x08\x63\x61tegory\x18\x03 \x01(\x0b\x32\x1f.social.product.ProductCategory\x12(\n\nmedia_list\x18\x04 \x03(\x0b\x32\x14.social.common.Media\"D\n\x12SubCategoryContent\x12.\n\x05items\x18\x01 \x03(\x0b\x32\x1f.social.product.SubCategoryItem\"J\n\tStyleStat\x12\x12\n\nlike_count\x18\x01 \x01(\x03\x12\x12\n\nview_count\x18\x02 \x01(\x03\x12\x15\n\rcomment_count\x18\x03 \x01(\x03\"\x87\x01\n\x0bStyleObject\x12\n\n\x02to\x18\x01 \x01(\t\x12\x13\n\x0bmedia_index\x18\x02 \x01(\x05\x12/\n\x08position\x18\x03 \x01(\x0e\x32\x1d.social.product.StylePosition\x12&\n\x05media\x18\x04 \x01(\x0b\x32\x17.social.product.Product\"\xf7\x01\n\nStyleMaker\x12\n\n\x02id\x18\x01 \x01(\t\x12(\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x17.social.account.Account\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12*\n\x05items\x18\x05 \x03(\x0b\x32\x1b.social.product.StyleObject\x12\'\n\x04stat\x18\x06 \x01(\x0b\x32\x19.social.product.StyleStat\x12\x11\n\tthumbnail\x18\t \x01(\t\x12\x12\n\ndeleted_at\x18\x07 \x01(\x05\x12\x13\n\x0b\x61rchived_at\x18\x08 \x01(\x05\"H\n\x13GetAllStylesRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\";\n\x0eStyleMakerList\x12)\n\x05items\x18\x01 \x03(\x0b\x32\x1a.social.product.StyleMaker\"\x87\x02\n\x06Review\x12\n\n\x02id\x18\x01 \x01(\t\x12(\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x17.social.account.Account\x12\x12\n\nproduct_id\x18\x03 \x01(\t\x12\x0f\n\x07\x63omment\x18\x04 \x01(\t\x12\x0c\n\x04rate\x18\x05 \x01(\x05\x12\x12\n\ncreated_at\x18\x06 \x01(\x03\x12\x10\n\x08is_buyer\x18\x07 \x01(\x08\x12$\n\x05offer\x18\x08 \x01(\x0e\x32\x15.social.product.Offer\x12\x34\n\x0epublish_status\x18\t \x01(\x0b\x32\x1c.social.common.PublishStatus\x12\x12\n\nupdated_at\x18\n \x01(\x03\"I\n\x14GetAllReviewsRequest\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\"B\n\nReviewList\x12%\n\x05items\x18\x01 \x03(\x0b\x32\x16.social.product.Review\x12\r\n\x05\x63ount\x18\x02 \x01(\x05*@\n\x08\x43urrency\x12\x07\n\x03IRR\x10\x00\x12\x07\n\x03USD\x10\x01\x12\x07\n\x03\x45UR\x10\x02\x12\x07\n\x03GBP\x10\x03\x12\x07\n\x03TRY\x10\x04\x12\x07\n\x03\x41\x45\x44\x10\x05*n\n\x06SortBy\x12\x10\n\x0cNEW_ARRIVALS\x10\x00\x12\r\n\tRECOMMEND\x10\x01\x12\x11\n\rPRICE_TO_HIGH\x10\x02\x12\x10\n\x0cPRICE_TO_LOW\x10\x03\x12\x10\n\x0cTOP_REVIEWED\x10\x04\x12\x0c\n\x08PROPERTY\x10\x05*L\n\rStylePosition\x12\x11\n\rTOP_ACCESSORY\x10\x00\x12\t\n\x05SHIRT\x10\x01\x12\t\n\x05PANTS\x10\x02\x12\t\n\x05SHOOS\x10\x03\x12\x07\n\x03\x42\x41G\x10\x04*#\n\x05Offer\x12\x06\n\x02NO\x10\x00\x12\x07\n\x03YES\x10\x01\x12\t\n\x05MAYBE\x10\x02\x32\xf8\x1e\n\x0eProductService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12;\n\x07Publish\x12\x17.social.product.Product\x1a\x17.social.product.Product\x12:\n\x06Update\x12\x17.social.product.Product\x1a\x17.social.product.Product\x12\x37\n\x06\x44\x65lete\x12\x17.social.product.Product\x1a\x14.social.common.Empty\x12:\n\x03Get\x12\x1a.social.product.GetProduct\x1a\x17.social.product.Product\x12G\n\x04\x46ind\x12\".social.product.FindProductRequest\x1a\x1b.social.product.ProductList\x12\x44\n\x06GetAll\x12\x1d.social.product.GetAllRequest\x1a\x1b.social.product.ProductList\x12G\n\rGetMyProducts\x12\x19.social.common.Pagination\x1a\x1b.social.product.ProductList\x12`\n\x10GetAllCategories\x12\'.social.product.GetAllCategoriesRequest\x1a#.social.product.ProductCategoryList\x12R\n\x0bGetCategory\x12\".social.product.GetCategoryRequest\x1a\x1f.social.product.ProductCategory\x12n\n\x17GetAllCategoriesWithSub\x12..social.product.GetAllCategoriesWithSubRequest\x1a#.social.product.ProductCategoryList\x12X\n\x0c\x46indCategory\x12#.social.product.FindCategoryRequest\x1a#.social.product.ProductCategoryList\x12T\n\x0bUploadMedia\x12!.social.common.UploadMediaRequest\x1a\".social.common.UploadMediaResponse\x12\\\n\x13UploadMediaCategory\x12!.social.common.UploadMediaRequest\x1a\".social.common.UploadMediaResponse\x12]\n\x14UploadStyleThumbnail\x12!.social.common.UploadMediaRequest\x1a\".social.common.UploadMediaResponse\x12\x45\n\x0fGetRootCategory\x12\x14.social.common.Empty\x1a\x1c.social.product.RootCategory\x12\\\n\x15GetSubCategoryContent\x12\x1f.social.product.ProductCategory\x1a\".social.product.SubCategoryContent\x12T\n\x13GetCategoryProperty\x12\x1f.social.product.ProductCategory\x1a\x1c.social.product.PropertyList\x12\x45\n\x0b\x43reateStyle\x12\x1a.social.product.StyleMaker\x1a\x1a.social.product.StyleMaker\x12\x45\n\x0bUpdateStyle\x12\x1a.social.product.StyleMaker\x1a\x1a.social.product.StyleMaker\x12?\n\x0b\x44\x65leteStyle\x12\x1a.social.product.StyleMaker\x1a\x14.social.common.Empty\x12@\n\x0c\x41rchiveStyle\x12\x1a.social.product.StyleMaker\x1a\x14.social.common.Empty\x12?\n\x0bPublicStyle\x12\x1a.social.product.StyleMaker\x1a\x14.social.common.Empty\x12\x42\n\x08GetStyle\x12\x1a.social.product.StyleMaker\x1a\x1a.social.product.StyleMaker\x12S\n\x0cGetAllStyles\x12#.social.product.GetAllStylesRequest\x1a\x1e.social.product.StyleMakerList\x12\x45\n\x0bGetFavorite\x12\x19.social.common.Pagination\x1a\x1b.social.product.ProductList\x12>\n\rAddToFavorite\x12\x17.social.product.Product\x1a\x14.social.common.Empty\x12\x43\n\x12RemoveFromFavorite\x12\x17.social.product.Product\x1a\x14.social.common.Empty\x12?\n\rPublishReview\x12\x16.social.product.Review\x1a\x16.social.product.Review\x12>\n\x0cUpdateReview\x12\x16.social.product.Review\x1a\x16.social.product.Review\x12<\n\x0c\x44\x65leteReview\x12\x16.social.product.Review\x1a\x14.social.common.Empty\x12Q\n\rGetAllReviews\x12$.social.product.GetAllReviewsRequest\x1a\x1a.social.product.ReviewList\x12X\n\x14GetUnApprovedReviews\x12$.social.product.GetAllReviewsRequest\x1a\x1a.social.product.ReviewList\x12;\n\tGetReview\x12\x16.social.product.Review\x1a\x16.social.product.Review\x12\x45\n\x0b\x41\x64minGetAll\x12\x19.social.common.Pagination\x1a\x1b.social.product.ProductList\x12X\n\x13\x41\x64minApproveProduct\x12+.social.product.ProductPublishStatusRequest\x1a\x14.social.common.Empty\x12W\n\x12\x41\x64minRejectProduct\x12+.social.product.ProductPublishStatusRequest\x1a\x14.social.common.Empty\x12S\n\x19\x41\x64minGetUnapprovedProduct\x12\x19.social.common.Pagination\x1a\x1b.social.product.ProductList\x12V\n\x12\x41\x64minApproveReview\x12*.social.product.ReviewPublishStatusRequest\x1a\x14.social.common.Empty\x12U\n\x11\x41\x64minRejectReview\x12*.social.product.ReviewPublishStatusRequest\x1a\x14.social.common.Empty\x12Q\n\x18\x41\x64minGetUnapprovedReview\x12\x19.social.common.Pagination\x1a\x1a.social.product.ReviewList\x12W\n\x16\x41\x64minGetReviewByStatus\x12!.social.product.GetReviewsRequest\x1a\x1a.social.product.ReviewList\x12I\n\x13\x41\x64minCreateProperty\x12\x18.social.product.Property\x1a\x18.social.product.Property\x12I\n\x13\x41\x64minUpdateProperty\x12\x18.social.product.Property\x1a\x18.social.product.Property\x12\x45\n\x13\x41\x64minDeleteProperty\x12\x18.social.product.Property\x1a\x14.social.common.Empty\x12P\n\x15\x41\x64minGetAllProperties\x12\x19.social.common.Pagination\x1a\x1c.social.product.PropertyList\x12M\n\x11\x41\x64minFindProperty\x12\x1a.social.common.FindRequest\x1a\x1c.social.product.PropertyList\x12W\n\x13\x41\x64minCreateCategory\x12\x1f.social.product.ProductCategory\x1a\x1f.social.product.ProductCategory\x12W\n\x13\x41\x64minUpdateCategory\x12\x1f.social.product.ProductCategory\x1a\x1f.social.product.ProductCategory\x12L\n\x13\x41\x64minDeleteCategory\x12\x1f.social.product.ProductCategory\x1a\x14.social.common.Empty\x12W\n\x10\x41\x64minGetCategory\x12\".social.product.GetCategoryRequest\x1a\x1f.social.product.ProductCategoryb\x06proto3')

_CURRENCY = DESCRIPTOR.enum_types_by_name['Currency']
Currency = enum_type_wrapper.EnumTypeWrapper(_CURRENCY)
_SORTBY = DESCRIPTOR.enum_types_by_name['SortBy']
SortBy = enum_type_wrapper.EnumTypeWrapper(_SORTBY)
_STYLEPOSITION = DESCRIPTOR.enum_types_by_name['StylePosition']
StylePosition = enum_type_wrapper.EnumTypeWrapper(_STYLEPOSITION)
_OFFER = DESCRIPTOR.enum_types_by_name['Offer']
Offer = enum_type_wrapper.EnumTypeWrapper(_OFFER)
IRR = 0
USD = 1
EUR = 2
GBP = 3
TRY = 4
AED = 5
NEW_ARRIVALS = 0
RECOMMEND = 1
PRICE_TO_HIGH = 2
PRICE_TO_LOW = 3
TOP_REVIEWED = 4
PROPERTY = 5
TOP_ACCESSORY = 0
SHIRT = 1
PANTS = 2
SHOOS = 3
BAG = 4
NO = 0
YES = 1
MAYBE = 2


_GETCATEGORYREQUEST = DESCRIPTOR.message_types_by_name['GetCategoryRequest']
_PRODUCTPUBLISHSTATUSREQUEST = DESCRIPTOR.message_types_by_name['ProductPublishStatusRequest']
_REVIEWPUBLISHSTATUSREQUEST = DESCRIPTOR.message_types_by_name['ReviewPublishStatusRequest']
_GETREVIEWSREQUEST = DESCRIPTOR.message_types_by_name['GetReviewsRequest']
_GETCATEGORYOPTIONS = DESCRIPTOR.message_types_by_name['GetCategoryOptions']
_GETALLCATEGORIESWITHSUBREQUEST = DESCRIPTOR.message_types_by_name['GetAllCategoriesWithSubRequest']
_GETALLCATEGORIESREQUEST = DESCRIPTOR.message_types_by_name['GetAllCategoriesRequest']
_FINDCATEGORYREQUEST = DESCRIPTOR.message_types_by_name['FindCategoryRequest']
_GETPRODUCT = DESCRIPTOR.message_types_by_name['GetProduct']
_GETALLREQUEST = DESCRIPTOR.message_types_by_name['GetAllRequest']
_STYLE = DESCRIPTOR.message_types_by_name['Style']
_PROPERTYVALUE = DESCRIPTOR.message_types_by_name['PropertyValue']
_PROPERTY = DESCRIPTOR.message_types_by_name['Property']
_PROPERTYLIST = DESCRIPTOR.message_types_by_name['PropertyList']
_PRODUCTCATEGORY = DESCRIPTOR.message_types_by_name['ProductCategory']
_PRODUCTCATEGORYLIST = DESCRIPTOR.message_types_by_name['ProductCategoryList']
_PRODUCTPROPERTYVALUE = DESCRIPTOR.message_types_by_name['ProductPropertyValue']
_PRODUCTSTAT = DESCRIPTOR.message_types_by_name['ProductStat']
_PRICING = DESCRIPTOR.message_types_by_name['Pricing']
_PRODUCTPRICE = DESCRIPTOR.message_types_by_name['ProductPrice']
_PRODUCT = DESCRIPTOR.message_types_by_name['Product']
_PRODUCTLIST = DESCRIPTOR.message_types_by_name['ProductList']
_PROPERTYFORFIND = DESCRIPTOR.message_types_by_name['PropertyForFind']
_FINDSORT = DESCRIPTOR.message_types_by_name['FindSort']
_FINDPRODUCTREQUEST = DESCRIPTOR.message_types_by_name['FindProductRequest']
_ROOTCATEGORY = DESCRIPTOR.message_types_by_name['RootCategory']
_SUBCATEGORYCONTENTREQUEST = DESCRIPTOR.message_types_by_name['SubCategoryContentRequest']
_SUBCATEGORYITEM = DESCRIPTOR.message_types_by_name['SubCategoryItem']
_SUBCATEGORYCONTENT = DESCRIPTOR.message_types_by_name['SubCategoryContent']
_STYLESTAT = DESCRIPTOR.message_types_by_name['StyleStat']
_STYLEOBJECT = DESCRIPTOR.message_types_by_name['StyleObject']
_STYLEMAKER = DESCRIPTOR.message_types_by_name['StyleMaker']
_GETALLSTYLESREQUEST = DESCRIPTOR.message_types_by_name['GetAllStylesRequest']
_STYLEMAKERLIST = DESCRIPTOR.message_types_by_name['StyleMakerList']
_REVIEW = DESCRIPTOR.message_types_by_name['Review']
_GETALLREVIEWSREQUEST = DESCRIPTOR.message_types_by_name['GetAllReviewsRequest']
_REVIEWLIST = DESCRIPTOR.message_types_by_name['ReviewList']
GetCategoryRequest = _reflection.GeneratedProtocolMessageType('GetCategoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCATEGORYREQUEST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.GetCategoryRequest)
  })
_sym_db.RegisterMessage(GetCategoryRequest)

ProductPublishStatusRequest = _reflection.GeneratedProtocolMessageType('ProductPublishStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTPUBLISHSTATUSREQUEST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.ProductPublishStatusRequest)
  })
_sym_db.RegisterMessage(ProductPublishStatusRequest)

ReviewPublishStatusRequest = _reflection.GeneratedProtocolMessageType('ReviewPublishStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWPUBLISHSTATUSREQUEST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.ReviewPublishStatusRequest)
  })
_sym_db.RegisterMessage(ReviewPublishStatusRequest)

GetReviewsRequest = _reflection.GeneratedProtocolMessageType('GetReviewsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREVIEWSREQUEST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.GetReviewsRequest)
  })
_sym_db.RegisterMessage(GetReviewsRequest)

GetCategoryOptions = _reflection.GeneratedProtocolMessageType('GetCategoryOptions', (_message.Message,), {
  'DESCRIPTOR' : _GETCATEGORYOPTIONS,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.GetCategoryOptions)
  })
_sym_db.RegisterMessage(GetCategoryOptions)

GetAllCategoriesWithSubRequest = _reflection.GeneratedProtocolMessageType('GetAllCategoriesWithSubRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLCATEGORIESWITHSUBREQUEST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.GetAllCategoriesWithSubRequest)
  })
_sym_db.RegisterMessage(GetAllCategoriesWithSubRequest)

GetAllCategoriesRequest = _reflection.GeneratedProtocolMessageType('GetAllCategoriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLCATEGORIESREQUEST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.GetAllCategoriesRequest)
  })
_sym_db.RegisterMessage(GetAllCategoriesRequest)

FindCategoryRequest = _reflection.GeneratedProtocolMessageType('FindCategoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDCATEGORYREQUEST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.FindCategoryRequest)
  })
_sym_db.RegisterMessage(FindCategoryRequest)

GetProduct = _reflection.GeneratedProtocolMessageType('GetProduct', (_message.Message,), {
  'DESCRIPTOR' : _GETPRODUCT,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.GetProduct)
  })
_sym_db.RegisterMessage(GetProduct)

GetAllRequest = _reflection.GeneratedProtocolMessageType('GetAllRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLREQUEST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.GetAllRequest)
  })
_sym_db.RegisterMessage(GetAllRequest)

Style = _reflection.GeneratedProtocolMessageType('Style', (_message.Message,), {
  'DESCRIPTOR' : _STYLE,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.Style)
  })
_sym_db.RegisterMessage(Style)

PropertyValue = _reflection.GeneratedProtocolMessageType('PropertyValue', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTYVALUE,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.PropertyValue)
  })
_sym_db.RegisterMessage(PropertyValue)

Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTY,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.Property)
  })
_sym_db.RegisterMessage(Property)

PropertyList = _reflection.GeneratedProtocolMessageType('PropertyList', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTYLIST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.PropertyList)
  })
_sym_db.RegisterMessage(PropertyList)

ProductCategory = _reflection.GeneratedProtocolMessageType('ProductCategory', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTCATEGORY,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.ProductCategory)
  })
_sym_db.RegisterMessage(ProductCategory)

ProductCategoryList = _reflection.GeneratedProtocolMessageType('ProductCategoryList', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTCATEGORYLIST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.ProductCategoryList)
  })
_sym_db.RegisterMessage(ProductCategoryList)

ProductPropertyValue = _reflection.GeneratedProtocolMessageType('ProductPropertyValue', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTPROPERTYVALUE,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.ProductPropertyValue)
  })
_sym_db.RegisterMessage(ProductPropertyValue)

ProductStat = _reflection.GeneratedProtocolMessageType('ProductStat', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTSTAT,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.ProductStat)
  })
_sym_db.RegisterMessage(ProductStat)

Pricing = _reflection.GeneratedProtocolMessageType('Pricing', (_message.Message,), {
  'DESCRIPTOR' : _PRICING,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.Pricing)
  })
_sym_db.RegisterMessage(Pricing)

ProductPrice = _reflection.GeneratedProtocolMessageType('ProductPrice', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTPRICE,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.ProductPrice)
  })
_sym_db.RegisterMessage(ProductPrice)

Product = _reflection.GeneratedProtocolMessageType('Product', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCT,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.Product)
  })
_sym_db.RegisterMessage(Product)

ProductList = _reflection.GeneratedProtocolMessageType('ProductList', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTLIST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.ProductList)
  })
_sym_db.RegisterMessage(ProductList)

PropertyForFind = _reflection.GeneratedProtocolMessageType('PropertyForFind', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTYFORFIND,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.PropertyForFind)
  })
_sym_db.RegisterMessage(PropertyForFind)

FindSort = _reflection.GeneratedProtocolMessageType('FindSort', (_message.Message,), {
  'DESCRIPTOR' : _FINDSORT,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.FindSort)
  })
_sym_db.RegisterMessage(FindSort)

FindProductRequest = _reflection.GeneratedProtocolMessageType('FindProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDPRODUCTREQUEST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.FindProductRequest)
  })
_sym_db.RegisterMessage(FindProductRequest)

RootCategory = _reflection.GeneratedProtocolMessageType('RootCategory', (_message.Message,), {
  'DESCRIPTOR' : _ROOTCATEGORY,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.RootCategory)
  })
_sym_db.RegisterMessage(RootCategory)

SubCategoryContentRequest = _reflection.GeneratedProtocolMessageType('SubCategoryContentRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBCATEGORYCONTENTREQUEST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.SubCategoryContentRequest)
  })
_sym_db.RegisterMessage(SubCategoryContentRequest)

SubCategoryItem = _reflection.GeneratedProtocolMessageType('SubCategoryItem', (_message.Message,), {
  'DESCRIPTOR' : _SUBCATEGORYITEM,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.SubCategoryItem)
  })
_sym_db.RegisterMessage(SubCategoryItem)

SubCategoryContent = _reflection.GeneratedProtocolMessageType('SubCategoryContent', (_message.Message,), {
  'DESCRIPTOR' : _SUBCATEGORYCONTENT,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.SubCategoryContent)
  })
_sym_db.RegisterMessage(SubCategoryContent)

StyleStat = _reflection.GeneratedProtocolMessageType('StyleStat', (_message.Message,), {
  'DESCRIPTOR' : _STYLESTAT,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.StyleStat)
  })
_sym_db.RegisterMessage(StyleStat)

StyleObject = _reflection.GeneratedProtocolMessageType('StyleObject', (_message.Message,), {
  'DESCRIPTOR' : _STYLEOBJECT,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.StyleObject)
  })
_sym_db.RegisterMessage(StyleObject)

StyleMaker = _reflection.GeneratedProtocolMessageType('StyleMaker', (_message.Message,), {
  'DESCRIPTOR' : _STYLEMAKER,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.StyleMaker)
  })
_sym_db.RegisterMessage(StyleMaker)

GetAllStylesRequest = _reflection.GeneratedProtocolMessageType('GetAllStylesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLSTYLESREQUEST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.GetAllStylesRequest)
  })
_sym_db.RegisterMessage(GetAllStylesRequest)

StyleMakerList = _reflection.GeneratedProtocolMessageType('StyleMakerList', (_message.Message,), {
  'DESCRIPTOR' : _STYLEMAKERLIST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.StyleMakerList)
  })
_sym_db.RegisterMessage(StyleMakerList)

Review = _reflection.GeneratedProtocolMessageType('Review', (_message.Message,), {
  'DESCRIPTOR' : _REVIEW,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.Review)
  })
_sym_db.RegisterMessage(Review)

GetAllReviewsRequest = _reflection.GeneratedProtocolMessageType('GetAllReviewsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLREVIEWSREQUEST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.GetAllReviewsRequest)
  })
_sym_db.RegisterMessage(GetAllReviewsRequest)

ReviewList = _reflection.GeneratedProtocolMessageType('ReviewList', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWLIST,
  '__module__' : 'services.product.product_pb2'
  # @@protoc_insertion_point(class_scope:social.product.ReviewList)
  })
_sym_db.RegisterMessage(ReviewList)

_PRODUCTSERVICE = DESCRIPTOR.services_by_name['ProductService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CURRENCY._serialized_start=4772
  _CURRENCY._serialized_end=4836
  _SORTBY._serialized_start=4838
  _SORTBY._serialized_end=4948
  _STYLEPOSITION._serialized_start=4950
  _STYLEPOSITION._serialized_end=5026
  _OFFER._serialized_start=5028
  _OFFER._serialized_end=5063
  _GETCATEGORYREQUEST._serialized_start=112
  _GETCATEGORYREQUEST._serialized_end=197
  _PRODUCTPUBLISHSTATUSREQUEST._serialized_start=199
  _PRODUCTPUBLISHSTATUSREQUEST._serialized_end=294
  _REVIEWPUBLISHSTATUSREQUEST._serialized_start=296
  _REVIEWPUBLISHSTATUSREQUEST._serialized_end=390
  _GETREVIEWSREQUEST._serialized_start=392
  _GETREVIEWSREQUEST._serialized_end=488
  _GETCATEGORYOPTIONS._serialized_start=490
  _GETCATEGORYOPTIONS._serialized_end=607
  _GETALLCATEGORIESWITHSUBREQUEST._serialized_start=609
  _GETALLCATEGORIESWITHSUBREQUEST._serialized_end=694
  _GETALLCATEGORIESREQUEST._serialized_start=696
  _GETALLCATEGORIESREQUEST._serialized_end=792
  _FINDCATEGORYREQUEST._serialized_start=794
  _FINDCATEGORYREQUEST._serialized_end=914
  _GETPRODUCT._serialized_start=916
  _GETPRODUCT._serialized_end=987
  _GETALLREQUEST._serialized_start=989
  _GETALLREQUEST._serialized_end=1055
  _STYLE._serialized_start=1057
  _STYLE._serialized_end=1153
  _PROPERTYVALUE._serialized_start=1155
  _PROPERTYVALUE._serialized_end=1254
  _PROPERTY._serialized_start=1257
  _PROPERTY._serialized_end=1436
  _PROPERTYLIST._serialized_start=1438
  _PROPERTYLIST._serialized_end=1493
  _PRODUCTCATEGORY._serialized_start=1496
  _PRODUCTCATEGORY._serialized_end=1955
  _PRODUCTCATEGORYLIST._serialized_start=1957
  _PRODUCTCATEGORYLIST._serialized_end=2026
  _PRODUCTPROPERTYVALUE._serialized_start=2028
  _PRODUCTPROPERTYVALUE._serialized_end=2105
  _PRODUCTSTAT._serialized_start=2107
  _PRODUCTSTAT._serialized_end=2183
  _PRICING._serialized_start=2185
  _PRICING._serialized_end=2292
  _PRODUCTPRICE._serialized_start=2295
  _PRODUCTPRICE._serialized_end=2428
  _PRODUCT._serialized_start=2431
  _PRODUCT._serialized_end=3031
  _PRODUCTLIST._serialized_start=3033
  _PRODUCTLIST._serialized_end=3086
  _PROPERTYFORFIND._serialized_start=3088
  _PROPERTYFORFIND._serialized_end=3139
  _FINDSORT._serialized_start=3141
  _FINDSORT._serialized_end=3236
  _FINDPRODUCTREQUEST._serialized_start=3239
  _FINDPRODUCTREQUEST._serialized_end=3390
  _ROOTCATEGORY._serialized_start=3392
  _ROOTCATEGORY._serialized_end=3454
  _SUBCATEGORYCONTENTREQUEST._serialized_start=3456
  _SUBCATEGORYCONTENTREQUEST._serialized_end=3550
  _SUBCATEGORYITEM._serialized_start=3553
  _SUBCATEGORYITEM._serialized_end=3692
  _SUBCATEGORYCONTENT._serialized_start=3694
  _SUBCATEGORYCONTENT._serialized_end=3762
  _STYLESTAT._serialized_start=3764
  _STYLESTAT._serialized_end=3838
  _STYLEOBJECT._serialized_start=3841
  _STYLEOBJECT._serialized_end=3976
  _STYLEMAKER._serialized_start=3979
  _STYLEMAKER._serialized_end=4226
  _GETALLSTYLESREQUEST._serialized_start=4228
  _GETALLSTYLESREQUEST._serialized_end=4300
  _STYLEMAKERLIST._serialized_start=4302
  _STYLEMAKERLIST._serialized_end=4361
  _REVIEW._serialized_start=4364
  _REVIEW._serialized_end=4627
  _GETALLREVIEWSREQUEST._serialized_start=4629
  _GETALLREVIEWSREQUEST._serialized_end=4702
  _REVIEWLIST._serialized_start=4704
  _REVIEWLIST._serialized_end=4770
  _PRODUCTSERVICE._serialized_start=5066
  _PRODUCTSERVICE._serialized_end=9026
# @@protoc_insertion_point(module_scope)
